import { createApp } from 'vue'
import { createPinia } from 'pinia'
import { MotionPlugin } from '@vueuse/motion'
import App from './App.vue'
import './style.css'

// --- Parse 初始化配置 ---
// 动态导入Parse以避免LiveQuery初始化问题
let Parse: any;

async function initializeParse() {
  try {
    // 设置环境变量禁用LiveQuery
    (window as any).process = { env: { PARSE_DISABLE_LIVEQUERY: 'true' } };
    
    // 动态导入Parse
    const ParseModule = await import('parse');
    Parse = ParseModule.default;
    
    // 初始化Parse
    Parse.initialize("myAppId", "myJavascriptKey");
    Parse.serverURL = "http://localhost:1337/parse";
    
    console.log("Parse SDK 成功初始化！");
  } catch (error) {
    console.error("Parse SDK 初始化失败:", error);
  }
}

// 异步初始化Parse
initializeParse();

const app = createApp(App)
const pinia = createPinia()

app.use(pinia)
app.use(MotionPlugin)

app.mount('#app')